==> libdatetime-locale-perl_1.24.orig.tar.gz: DateTime-Locale-1.24/share/fr-CA.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h 'h' B",
    Bhm => "h 'h' mm B",
    Bhms => "h 'h' mm 'min' ss 's' B",
    E => "E",
    EBhm => "E h 'h' mm B",
    EBhms => "E h 'h' mm 'min' ss 's' B",
    EHm => "E HH 'h' mm",
    EHms => "E HH 'h' mm 'min' ss 's'",
    Ed => "E d",
    Ehm => "E h 'h' mm a",
    Ehms => "E h 'h' mm 'min' ss 's' a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH 'h'",
    Hm => "HH 'h' mm",
    Hms => "HH 'h' mm 'min' ss 's'",
    Hmsv => "HH 'h' mm 'min' ss 's' v",
    Hmv => "HH 'h' mm v",
    M => "L",
    MEd => "E M-d",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'semaine' W (MMMM)",
    "MMMMW-count-other" => "'semaine' W (MMMM)",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "MM-d",
    MMdd => "MM-dd",
    Md => "M-d",
    d => "d",
    h => "h 'h' a",
    hm => "h 'h' mm a",
    hms => "h 'h' mm 'min' ss 's' a",
    hmsv => "h 'h' mm 'min' ss 's' a v",
    hmv => "h 'h' mm a v",
    ms => "mm 'min' ss 's'",
    y => "y",
    yM => "y-MM",
    yMEd => "E y-MM-dd",
    yMM => "y-MM",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'semaine' w 'de' Y",
    "yw-count-other" => "'semaine' w 'de' Y",
  },
  code => "fr-CA",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "yy-MM-dd",
  datetime_format_full => "{1} '\N{U+00e0}' {0}",
  datetime_format_long => "{1} '\N{U+00e0}' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  era_abbreviated => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_narrow => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_wide => [
    "avant J\N{U+00e9}sus-Christ",
    "apr\N{U+00e8}s J\N{U+00e9}sus-Christ",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "French",
  month_format_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juill.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  month_stand_alone_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juill.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  name => "French Canada",
  native_language => "fran\N{U+00e7}ais",
  native_name => "fran\N{U+00e7}ais Canada",
  native_script => undef,
  native_territory => "Canada",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  script => undef,
  territory => "Canada",
  time_format_full => "HH 'h' mm 'min' ss 's' zzzz",
  time_format_long => "HH 'h' mm 'min' ss 's' z",
  time_format_medium => "HH 'h' mm 'min' ss 's'",
  time_format_short => "HH 'h' mm",
  variant => undef,
  version => 35,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/fr-CA.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h 'h' B",
    Bhm => "h 'h' mm B",
    Bhms => "h 'h' mm 'min' ss 's' B",
    E => "E",
    EBhm => "E h 'h' mm B",
    EBhms => "E h 'h' mm 'min' ss 's' B",
    EHm => "E HH 'h' mm",
    EHms => "E HH 'h' mm 'min' ss 's'",
    Ed => "E d",
    Ehm => "E h 'h' mm\N{U+202f}a",
    Ehms => "E h 'h' mm 'min' ss 's' a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "y-MM-dd GGGGG",
    H => "HH 'h'",
    Hm => "HH 'h' mm",
    Hms => "HH 'h' mm 'min' ss 's'",
    Hmsv => "HH 'h' mm 'min' ss 's' v",
    Hmv => "HH 'h' mm v",
    M => "L",
    MEd => "E M-d",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'semaine' W (MMMM)",
    "MMMMW-count-other" => "'semaine' W (MMMM)",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "MM-d",
    MMdd => "MM-dd",
    Md => "M-d",
    d => "d",
    h => "h 'h' a",
    hm => "h 'h' mm\N{U+202f}a",
    hms => "h 'h' mm 'min' ss 's' a",
    hmsv => "h 'h' mm 'min' ss 's' a v",
    hmv => "h 'h' mm\N{U+202f}a v",
    ms => "mm 'min' ss 's'",
    y => "y",
    yM => "y-MM",
    yMEd => "E y-MM-dd",
    yMM => "y-MM",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'semaine' w 'de' Y",
    "yw-count-other" => "'semaine' w 'de' Y",
  },
  code => "fr-CA",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  era_abbreviated => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_narrow => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_wide => [
    "avant J\N{U+00e9}sus-Christ",
    "apr\N{U+00e8}s J\N{U+00e9}sus-Christ",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "French",
  month_format_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juill.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  month_stand_alone_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juill.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  name => "French Canada",
  native_language => "fran\N{U+00e7}ais",
  native_name => "fran\N{U+00e7}ais Canada",
  native_script => undef,
  native_territory => "Canada",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  script => undef,
  territory => "Canada",
  time_format_full => "HH 'h' mm 'min' ss 's' zzzz",
  time_format_long => "HH 'h' mm 'min' ss 's' z",
  time_format_medium => "HH 'h' mm 'min' ss 's'",
  time_format_short => "HH 'h' mm",
  variant => undef,
  version => 42,
}
